==> huaweicloudsdkecs-3.0.2b0-py3-none-any.whl: huaweicloudsdkecs/v2/model/nova_security_group_common_ip_range.py <==
# coding: utf-8

import pprint
import re

import six


class NovaSecurityGroupCommonIpRange(object):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    openapi_types = {
        'cidr': 'str'
    }

    attribute_map = {
        'cidr': 'cidr'
    }

    def __init__(self, cidr=None):  # noqa: E501
        """NovaSecurityGroupCommonIpRange - a model defined in huaweicloud sdk"""

        self._cidr = None
        self.discriminator = None

        self.cidr = cidr

    @property
    def cidr(self):
        """Gets the cidr of this NovaSecurityGroupCommonIpRange.

        对端IP网段，cidr格式。

        :return: The cidr of this NovaSecurityGroupCommonIpRange.
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this NovaSecurityGroupCommonIpRange.

        对端IP网段，cidr格式。

        :param cidr: The cidr of this NovaSecurityGroupCommonIpRange.
        :type: str
        """
        self._cidr = cidr

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NovaSecurityGroupCommonIpRange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkecs-3.0.23b0-py3-none-any.whl: huaweicloudsdkecs/v2/model/nova_security_group_common_ip_range.py <==
# coding: utf-8

import pprint
import re

import six





class NovaSecurityGroupCommonIpRange:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'cidr': 'str'
    }

    attribute_map = {
        'cidr': 'cidr'
    }

    def __init__(self, cidr=None):
        """NovaSecurityGroupCommonIpRange - a model defined in huaweicloud sdk"""
        
        

        self._cidr = None
        self.discriminator = None

        self.cidr = cidr

    @property
    def cidr(self):
        """Gets the cidr of this NovaSecurityGroupCommonIpRange.

        对端IP网段，cidr格式。

        :return: The cidr of this NovaSecurityGroupCommonIpRange.
        :rtype: str
        """
        return self._cidr

    @cidr.setter
    def cidr(self, cidr):
        """Sets the cidr of this NovaSecurityGroupCommonIpRange.

        对端IP网段，cidr格式。

        :param cidr: The cidr of this NovaSecurityGroupCommonIpRange.
        :type: str
        """
        self._cidr = cidr

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NovaSecurityGroupCommonIpRange):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
